@@ -1,6 +1,6 @@
 package MooX::StrictHas;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 # this bit would be MooX::Utils but without initial _ on func name
 use strict;
@@ -33,6 +33,7 @@ sub import {
       : ()
       for sort keys %ATTR2MESSAGE;
     croak join "\n", @messages if @messages;
+    $orig->($namespec, %opts);
   });
 }
 
@@ -80,7 +81,7 @@ This is not considered best practice - just dereference in your using code.
 
 =item lazy_build
 
-Use C<is => 'lazy'> instead.
+Use C<is =E<gt> 'lazy'> instead.
 
 =back
 
